@@ -11,6 +11,7 @@ import os
 import urllib
 from http.client import HTTPResponse
 from math import degrees, sqrt
+from pathlib import Path
 from shutil import copyfileobj
 from typing import Iterator, List, Tuple, Dict, Union, TextIO
 
@@ -31,6 +32,8 @@ from scipy import spatial
 
 from atligator.geometry import InternalCoordinates, Matrix
 
+logger = logging.getLogger(__name__)
+
 # typedef "forwarded" from module atligator.structure
 LigandInfo = Tuple[str, str, str]  # (chain_id, residue_id, new_residue_type)
 BinderInfo = Tuple[str, str]  # (chain_id, residue_id)
@@ -974,11 +977,19 @@ def download_pdbs_by_scop_query(query: str, dest_dir: str, scop_dir_cla_file: st
     if not os.path.exists(dest_dir):
         os.makedirs(dest_dir)
     pdbkeys = get_structures_matching_scop_query(query=query, scop_dir_cla_file=scop_dir_cla_file)
-    print("Found no matching files." if not len(pdbkeys) else f"Found {len(pdbkeys)} matching pdb files.")
+    if not len(pdbkeys):
+        logger.warning("Found no matching files.")
+    else:
+        logger.info(f"Found {len(pdbkeys)} matching pdb files.")
     for k in pdbkeys:
         out_file = get_pdb_structure(pdb_key=k, dest_dir=dest_dir, pdb_db_path=pdb_db_path, local=local_db)
         if not os.path.isfile(out_file):
             logging.warning(f"The file {out_file} cannot be found in the pdb database.")
+        else:
+            logger.info(f'Downloading {out_file} and renaming to '
+                        f'{Path(out_file).parent / Path(out_file).name.replace("pdb", "").replace(".ent", ".pdb")}')
+            Path(out_file).rename(
+                Path(out_file).parent / Path(out_file).name.replace("pdb", "").replace(".ent", ".pdb"))
 
 
 class ChainSelect(Select):
